@@ -12,7 +12,7 @@ pub struct Dataloader<D: Sync + Send + Clone, S: Sync + Send> {
     chunks_processed: Vec<bool>,
     post_buffer: VecDeque<Vec<D>>,
     loading_state: Option<S>,
-    loading_function: fn(&String, Option<&S>) -> D,
+    loading_function: fn(&str, Option<&S>) -> D,
     sorting_function: Option<fn(&D, &D) -> Ordering>,
     current_index: usize,
 }
@@ -37,11 +37,11 @@ impl <D: Sync + Send + Clone, S: Sync + Send> Default for Dataloader<D, S> {
 
 impl<D: Sync + Send + Clone, S: Sync + Send> Dataloader <D, S>{
     #[allow(clippy::too_many_arguments)]
-    pub fn new(paths: &[&str], batch_size: usize, start_index: Option<usize>, end_index: Option<usize>, chunk_size: usize, loading_state: Option<S>, loading_function: fn(&String, Option<&S>) -> D, sorting_function: Option<fn(&D, &D) -> Ordering>) -> Self {
+    pub fn new(paths: &[&str], batch_size: usize, start_index: Option<usize>, end_index: Option<usize>, chunk_size: usize, loading_state: Option<S>, loading_function: fn(&str, Option<&S>) -> D, sorting_function: Option<fn(&D, &D) -> Ordering>) -> Self {
         // Find end index
         let end_index = {
             let mut file_end = 0;
-            for path in paths.clone() {
+            for path in paths {
                 let file = File::open(path).expect("Failed to read file!");
                 let reader = BufReader::new(file);
                 file_end += reader.lines().count();
@@ -53,12 +53,16 @@ impl<D: Sync + Send + Clone, S: Sync + Send> Dataloader <D, S>{
             }
         };
         let start_index = start_index.unwrap_or_default();
+        if end_index - start_index == 0 {
+            panic!("End Index and Start Index are the same!");
+        }
+        let chunk_size = usize::min(chunk_size, end_index - start_index);
         Dataloader{
             paths: paths.iter().map(|p| {p.to_string()}).collect(),
             batch_size,
             start_index,
             end_index,
-            chunk_size: usize::min(chunk_size, end_index - start_index),
+            chunk_size,
             loading_state,
             loading_function,
             sorting_function,
