@@ -18,7 +18,7 @@ pub struct ThreadedDataloader<D: Sync + Send + Clone, S: Sync + Send + Clone + '
     loading_process: Option<thread::JoinHandle<()>>,
     loading_process_flag: Option<thread_control::Flag>,
     loading_state: Option<S>,
-    loading_function: fn(&String, Option<&S>) -> D,
+    loading_function: fn(&str, Option<&S>) -> D,
     sorting_function: Option<fn(&D, &D) -> Ordering>,
     current_index: usize,
 }
@@ -47,11 +47,11 @@ impl <D: Sync + Send + Clone, S: Sync + Send + Clone + 'static> Default for Thre
 
 impl<D: Sync + Send + Clone + 'static, S: Sync + Send + Clone + 'static> ThreadedDataloader <D, S>{
     #[allow(clippy::too_many_arguments)]
-    pub fn new(paths: &[&str], batch_size: usize, start_index: Option<usize>, end_index: Option<usize>, chunk_size: usize, loading_state: Option<S>, loading_function: fn(&String, Option<&S>) -> D, sorting_function: Option<fn(&D, &D) -> Ordering>) -> Self {
+    pub fn new(paths: &[&str], batch_size: usize, start_index: Option<usize>, end_index: Option<usize>, chunk_size: usize, loading_state: Option<S>, loading_function: fn(&str, Option<&S>) -> D, sorting_function: Option<fn(&D, &D) -> Ordering>) -> Self {
         // Find end index
         let end_index = {
             let mut file_end = 0;
-            for path in paths.clone() {
+            for path in paths {
                 let file = File::open(path).expect("Failed to read file!");
                 let reader = BufReader::new(file);
                 file_end += reader.lines().count();
@@ -63,14 +63,18 @@ impl<D: Sync + Send + Clone + 'static, S: Sync + Send + Clone + 'static> Threade
             }
         };
         let start_index = start_index.unwrap_or_default();
+        if end_index - start_index == 0 {
+            panic!("End Index and Start Index are the same!");
+        }
         // Create post buffer queue
         let (send, recv) = broadcast_queue::<Vec<D>>(100);
+        let chunk_size = usize::min(chunk_size, end_index - start_index);
         ThreadedDataloader{
             paths: paths.iter().map(|p| {p.to_string()}).collect(),
             batch_size,
             start_index,
             end_index,
-            chunk_size: usize::min(chunk_size, end_index - start_index),
+            chunk_size,
             loading_state,
             loading_function,
             sorting_function,
@@ -179,7 +183,7 @@ impl <D: Sync + Send + Clone + 'static, S: Sync + Send + Clone + 'static> Iterat
             // Check if we need to start loading again
             if self.post_buffer.len() < self.chunk_size / self.batch_size {
                 // Trigger loading if possible
-                if (self.loading_process_flag.is_none() || !self.loading_process_flag.as_ref().unwrap().is_alive()) && !self.chunks_processed.iter().all(|v| {*v}) {
+                if (self.loading_process.is_none() || self.loading_process_flag.is_none() || !self.loading_process_flag.as_ref().unwrap().is_alive()) && !self.chunks_processed.iter().all(|v| {*v}) {
                     self.load().expect("Failed to load!");
                 }
                 // Make sure we have examples
